@@ -1,9 +1,9 @@
 /*
- *  $Id: editbox.c,v 1.43 2007/06/04 22:20:40 tom Exp $
+ *  $Id: editbox.c,v 1.46 2008/06/21 12:07:54 tom Exp $
  *
- * editbox.c -- implements the edit box
+ *  editbox.c -- implements the edit box
  *
- * Copyright 2007 Thomas E. Dickey
+ *  Copyright 2007,2008 Thomas E. Dickey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License, version 2.1
@@ -93,12 +93,17 @@ load_list(const char *file, char ***list, int *rows)
 	    }
 	}
 	if (pass) {
-	    for (n = 0; n < need; ++n) {
-		(*list)[n] = dlg_strclone((*list)[n]);
+	    if (need == 0) {
+		(*list)[0] = dlg_strclone("");
+		(*list)[1] = 0;
+	    } else {
+		for (n = 0; n < need; ++n) {
+		    (*list)[n] = dlg_strclone((*list)[n]);
+		}
+		(*list)[need] = 0;
 	    }
-	    (*list)[need] = 0;
 	} else {
-	    grow_list(list, rows, need);
+	    grow_list(list, rows, need + 1);
 	}
     }
     free(blob);
@@ -239,15 +244,21 @@ col_to_chr_offset(const char *text, int col)
 {
     const int *cols = dlg_index_columns(text);
     const int *indx = dlg_index_wchars(text);
+    bool found = FALSE;
     int result = 0;
     unsigned n;
     unsigned len = dlg_count_wchars(text);
+
     for (n = 0; n < len; ++n) {
 	if (cols[n] <= col && cols[n + 1] > col) {
 	    result = indx[n];
+	    found = TRUE;
 	    break;
 	}
     }
+    if (!found && len && cols[len] == col) {
+	result = indx[len];
+    }
     return result;
 }
 
@@ -310,8 +321,12 @@ dlg_editbox(const char *title,
     bool show_all, show_one, was_mouse;
     WINDOW *dialog;
     WINDOW *editing;
+    DIALOG_VARS save_vars;
     const char **buttons = dlg_ok_labels();
 
+    dlg_save_vars(&save_vars);
+    dialog_vars.separate_output = TRUE;
+
     dlg_does_output();
 
     buffer = dlg_malloc(char, max_len);
@@ -511,7 +526,7 @@ dlg_editbox(const char *title,
 			    assert_ptr(tmp, "dlg_editbox");
 
 			    chr_offset = dlg_count_wchars(PREV_ROW);
-			    UPDATE_COL(THIS_ROW);
+			    UPDATE_COL(PREV_ROW);
 			    goal_col = col_offset;
 
 			    sprintf(tmp, "%s%s", PREV_ROW, THIS_ROW);
@@ -646,10 +661,11 @@ dlg_editbox(const char *title,
 	int n;
 	for (n = 0; n < listsize; ++n) {
 	    dlg_add_result((*list)[n]);
-	    dlg_add_result("\n");
+	    dlg_add_separator();
 	}
     }
     free(buffer);
+    dlg_restore_vars(&save_vars);
     return result;
 }
 
